@@ -1,4 +1,4 @@
-# pylint: disable=missing-docstring, invalid-name
+# pylint: disable=missing-docstring, invalid-name, too-few-public-methods, no-self-use
 
 def test_regression_737():
     import xml # [unused-variable]
@@ -20,3 +20,12 @@ def test_local_field_prefixed_with_unused_or_ignored():
     flagged_local_field = 42 # [unused-variable]
     unused_local_field = 42
     ignored_local_field = 42
+
+
+class HasUnusedDunderClass(object):
+
+    def test(self):
+        __class__ = 42  # [unused-variable]
+
+    def best(self):
+        self.test()
